@@ -382,7 +382,7 @@ indentation style. At present, predefined style are `BSD', `GNU', `K&R', `C++',
 	   ess-mode-editing-alist))
   (ess-setq-vars-local ess-mode-editing-alist)
 
-  (ess-set-style ess-style)
+  (ess-set-style ess-style t)
   (use-local-map ess-mode-map)
   (set-syntax-table ess-mode-syntax-table)
 
@@ -418,7 +418,10 @@ indentation style. At present, predefined style are `BSD', `GNU', `K&R', `C++',
 	'(" [" (ess-local-process-name ess-local-process-name "none") "]"))
   ;; SJE Tue 28 Dec 2004: do not attempt to load object name db.
   ;; (ess-load-object-name-db-file)
-  (run-mode-hooks 'ess-mode-hook)
+  (if (> emacs-major-version 21)
+      (run-mode-hooks 'ess-mode-hook)
+    ;; old emacs 21.x
+    (run-hooks 'ess-mode-hook))
   (ess-write-to-dribble-buffer "\nFinished setting up ESS-mode.\n"))
 
 ;;*;; User commands in ess-mode
